<?php

/**
 * Plugin Name: 一言
 * Version: 1.0.0
 * Plugin URL: https://utf-x.cn/emlog-plugin-hitokoto/
 * Description: 在Emlog页面底部和后台首页显示一条一言（Hitokoto）
 * ForEmlog: Pro
 * Author: UTF-X
 * Author URL: https://utf-x.cn/
 */

!defined('EMLOG_ROOT') && exit('access denied!');

class HitokotoPlugin
{
    private $storage;
    public function __construct()
    {
        $this->storage = Storage::getInstance('hitokoto');
    }


    public function getSettingData($key)
    {
        return $this->storage->getValue($key);
    }
    public function getHitokotoData(...$keys)
    {
        $categoryParams = implode('&c=', $this->getSettingData('c'));
        $url = 'https://v1.hitokoto.cn/?c=' . $categoryParams;
        $ch = curl_init();
        curl_setopt($ch, CURLOPT_URL, $url);
        curl_setopt($ch, CURLOPT_RETURNTRANSFER, true);
        curl_setopt($ch, CURLOPT_TIMEOUT, 2);
        $response = curl_exec($ch);
        curl_close($ch);

        if (!$response) {
            return null;
        }
        $hitokotoData = json_decode($response, true);

        if (empty($keys)) {
            return $hitokotoData;
        }

        $result = array();

        foreach ($keys as $key) {
            if (array_key_exists($key, $hitokotoData)) {
                if ($key === 'type') {
                    $typeMap = [
                        'a' => '动画',
                        'b' => '漫画',
                        'c' => '游戏',
                        'd' => '文学',
                        'e' => '原创',
                        'f' => '来自网络',
                        'g' => '其他',
                        'h' => '影视',
                        'i' => '诗词',
                        'j' => '网易云',
                        'k' => '哲学',
                        'l' => '抖机灵',
                    ];
                    $result[$key] = isset($typeMap[$hitokotoData[$key]]) ? $typeMap[$hitokotoData[$key]] : '';
                } else {
                    $result[$key] = htmlspecialchars($hitokotoData[$key]);
                }
            }
        }
        return $result;
    }

    public function indexFooter()
    {
        $hitokoto = $this->getHitokotoData('hitokoto','type','from','from_who');
        $footerstyle=$this->getSettingData('footerstyle');
        echo str_replace(["{hitokoto}","{type}","{from}","{author}"],[$hitokoto['hitokoto'],$hitokoto['type'],$hitokoto['from'],$hitokoto['from_who']],$footerstyle);
    }

    public function admMainTop()
    {
        $hitokotoData = $this->getHitokotoData('hitokoto', 'from');
        if (isset($hitokotoData['hitokoto']) && isset($hitokotoData['from'])) {
            $hitokoto= $hitokotoData['hitokoto'] . ' ——' . $hitokotoData['from'];
        } else {
            $hitokoto= 'Hitokoto!';
        }
        echo '<p>' . $hitokoto . '</p>';
    }

}

$hitokotoPlugin = new HitokotoPlugin();
$settingData = $hitokotoPlugin->getSettingData('status');
if (in_array('indexFooter', $settingData)) {
    addAction('index_footer', array($hitokotoPlugin, 'indexFooter'));
}
if (in_array('admMainTop', $settingData)) {
    addAction('adm_main_top', array($hitokotoPlugin, 'admMainTop'));
}